@@ -40,6 +40,8 @@ OC.L10N.register(
     "Takes a link and adds it to your collection of bookmarks." : "Отримує посилання та додає до вашої колекції закладок.",
     "Bookmarks Backups" : "Резервні копії закладок",
     "Collect and manage bookmarks, synced with all your devices" : "Збирайте та впорядковуйте закладки, які синхронізуються зі всіма вашими пристроями",
+    "Do you really want to delete this bookmark?" : "Дічно вилучити цю закладку?",
+    "Link copied to clipboard" : "Посилання скопійовано в буфер обміну",
     "Enter new title" : "Зазначте новий заголовок",
     "Select bookmark" : "Вибрати закладку",
     "You have never clicked this link" : "Ви раніше не переходили за цим посиланням",
@@ -52,8 +54,6 @@ OC.L10N.register(
     "Put bookmark into trash bin" : "Вилучити закладку",
     "Restore bookmark" : "Відновити закладку",
     "Delete bookmark permanently" : "Вилучити закладку назавжди",
-    "Do you really want to delete this bookmark?" : "Дічно вилучити цю закладку?",
-    "Link copied to clipboard" : "Посилання скопійовано в буфер обміну",
     "Content pending" : "Отримання вмісту",
     "This content is being downloaded for offline use. Please check back later." : "Вміст звантажується для використання в автономному режимі. Будь ласка, перевірте пізніше.",
     "Bookmarked {time} ago" : "Закладку створено {time} назад",
@@ -65,14 +65,23 @@ OC.L10N.register(
     "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Закладки на посилання в мережі періодично перевіряються на доступність. Закладки, до яких відсутній доступ, буде наведено тут.",
     "You can share bookmark folders with others. All folders shared with you are listed here." : "Ви можете поділитися каталогами закладок з іншими користувачами. Усі каталоги, якими поділилися з вами, буде наведено тут.",
     "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Одна й та саме закладка може міститися одночасно в різних каталогах. Внесення змін до такої закладки оновить всі її копії. Повторювані закладки наведено тут для зручности.",
+    "Selected {folders} folders and {bookmarks} bookmarks" : "Вибрано {folders} каталогів та {bookmarks} закладок",
+    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Вибрано %n закладку","Вибрано %n закладки","Вибрано %n закладок","Вибрано %n закладок"],
+    "_Selected %n folder_::_Selected %n folders_" : ["Вибрано %n каталог","Вибрано %n каталоги","Вибрано %n каталогів","Вибрано %n каталогів"],
+    "Do you really want to delete these items?" : "Дійсно вилучити ці об'єкти?",
     "Open all selected" : "Відкрити всі вибрані",
     "Move selection" : "Перемістити вибране",
     "Edit tags of selection" : "Редагувати мітки вибраного",
     "Delete selection" : "Прибрати виділення",
     "Select all" : "Вибрати все",
     "Cancel selection" : "Скасувати вибір",
-    "Selected {folders} folders and {bookmarks} bookmarks" : "Вибрано {folders} каталогів та {bookmarks} закладок",
-    "Do you really want to delete these items?" : "Дійсно вилучити ці об'єкти?",
+    "Sort by created date" : "Впорядкувати за датою створення",
+    "Sort by last modified" : "Впорядкувати за останніми змінами",
+    "Sort by title" : "Впорядкувати за назвою",
+    "Sort by click count" : "Впорядкувати за кількістю переходів",
+    "Sort by manual order" : "Впорядкувати вручну",
+    "Sort by URL" : "Впорядкувати за посиланнями",
+    "RSS feed copied" : "Стрічку RSS скопійовано",
     "Trash Bin" : "Кошик",
     "Go back" : "Повернутися назад",
     "Share folder" : "Спільний доступ до каталогу",
@@ -87,21 +96,18 @@ OC.L10N.register(
     "The RSS feed requires authentication with your Nextcloud credentials" : "Стрічка RSS вимагає авторизації з вашим обліковим записом у хмарі Nextcloud",
     "Search" : "Пошук",
     "Empty trash bin" : "Очистити кошик",
-    "Sort by created date" : "Впорядкувати за датою створення",
-    "Sort by last modified" : "Впорядкувати за останніми змінами",
-    "Sort by title" : "Впорядкувати за назвою",
-    "Sort by click count" : "Впорядкувати за кількістю переходів",
-    "Sort by manual order" : "Впорядкувати вручну",
-    "Sort by URL" : "Впорядкувати за посиланнями",
-    "RSS feed copied" : "Стрічку RSS скопійовано",
+    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Додати %n закладку до нового каталогу","Додати %n закладки до нового каталогу","Додати %n закладок до нового каталогу","Додати %n закладок до нового каталогу"],
     "Enter a link" : "Зазначте посилання",
     "Enter a title" : "Зазначте заголовок",
     "No bookmarks found" : "Закладки не знайдено",
     "{folders} folders and {bookmarks} bookmarks" : "{folders} каталогів та {bookmarks} закладок",
+    "_%n bookmark_::_%n bookmarks_" : ["%n закладка","%n закладки","%n закладок","%n закладок"],
+    "_%n folder_::_%n folders_" : ["%n каталог","%n каталоги","%n каталогів","%n каталогів"],
     "Welcome to Bookmarks" : "Вітаємо у застосунку \"Закладки\"",
     "Add a bookmark" : "Додати закладку",
     "Import bookmarks" : "Імпорт закладок",
     "Sync with your browser" : "Синхронізувати з бравзером",
+    "Do you really want to permanently delete this folder?" : "Дійсно вилучити цей каталог без можливості відновлення?",
     "Select folder" : "Виберіть каталог",
     "Enter folder title" : "Зазначте назву каталогу",
     "Shared by {user}" : "{user} надав(-ла) доступ",
@@ -110,7 +116,6 @@ OC.L10N.register(
     "Put folder into trashbin" : "Вилучити каталог",
     "Restore folder" : "Відновити каталог",
     "Delete folder permanently" : "Вилучити каталог назавжди",
-    "Do you really want to permanently delete this folder?" : "Дійсно вилучити цей каталог без можливості відновлення?",
     "Choose folder" : "Виберіть каталог",
     "Submit" : "Гаразд",
     "Cancel" : "Скасувати",
@@ -120,6 +125,9 @@ OC.L10N.register(
     "Moving selection" : "Переміщення вибраного",
     "Adding selection to folders" : "Додавання вибору до каталогів",
     "Emptying trashbin" : "Очистка кошика",
+    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Переміщення %n каталогу та закладок","Переміщення %n каталогів та закладок","Переміщення %n каталогів та закладок","Переміщення %n каталогів та закладок"],
+    "_Moving %n folder_::_Moving %n folders_" : ["Переміщення %n каталогу","Переміщення %n каталогів","Переміщення %n каталогів","Переміщення %n каталогів"],
+    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Переміщення %n закладки","Переміщення %n закладок","Переміщення %n закладок","Переміщення %n закладок"],
     "All bookmarks" : "Усі закладки",
     "Recent" : "Останні",
     "Shared with you" : "Спільні",
@@ -131,7 +139,7 @@ OC.L10N.register(
     "Delete" : "Вилучити",
     "Untagged" : "Без мітки",
     "{used} bookmarks of {available} available" : "{used} із {available} закладок доступно",
-    "Bookmarks Settings" : "Налаштування закладок",
+    "Bookmarks Settings" : "Налаштування",
     "No bookmarked files" : "Відсутні закладки з файлами",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Закладки на файли, такі як світлини або файли PDF, буде автоматично збережено до ваших файлів у хмарі Nextcloud. Таким чином ви зможете завжди їх знаходити, навіть якщо посилання будуть недоступні.",
     "Nothing found" : "Нічого не знайдено",
@@ -143,7 +151,10 @@ OC.L10N.register(
     "You haven't deleted anything yet." : "Ви поки не перемістили жодної закладки до кошика.",
     "No bookmarks here" : "Тут відсутні закладки",
     "Add bookmarks manually or import bookmarks from a HTML file." : "Додайте закладки вручну або імпортуйте з файлу HTML.",
-    "Bookmarks settings" : "Налаштування закладок",
+    "Archive path" : "Шлях до архівних копій",
+    "Backup path" : "Шлях до резервних копій",
+    "Please select \"Add to home screen\" in your browser menu" : "Виберіть \"Додати на Домівку\" у налаштуваннях бравзера",
+    "Bookmarks settings" : "Налаштування",
     "Import/Export" : "Імпорт/експорт",
     "Export bookmarks" : "Експорт закладок",
     "Auto-archiving" : "Архівні копії",
@@ -166,9 +177,6 @@ OC.L10N.register(
     "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Якщи ви стикнетеся з проблемами в роботі застосунку \"Закладки\" або маєте пропозиції з удосконалення, просимо контактувати з нами.",
     "Support this project" : "Підтримати",
     "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Моя робота над застосунком \"Закладки\" основана на моделі волонтерської передплати. Якщо ви оцінили її результат, буду вдячний за будь-яку підтримку з вашого боку. Також прош оцінити застосунок у крамниці застосунків Nextcloud. Дякую вам 💙",
-    "Archive path" : "Шлях до архівних копій",
-    "Backup path" : "Шлях до резервних копій",
-    "Please select \"Add to home screen\" in your browser menu" : "Виберіть \"Додати на Домівку\" у налаштуваннях бравзера",
     "(Empty title)" : "(Без заголовку)",
     "Title" : "Назва",
     "Link" : "Посилання",
@@ -181,8 +189,7 @@ OC.L10N.register(
     "Archived file" : "Архівні файли",
     "Download file" : "Звантажити файл",
     "Open file location" : "Відкрити розташування файлу",
-    "Created {time} ago" : "Створено {time} тому",
-    "Created on {date}" : "Створено {date}",
+    "Link copied" : "Посилання скопійовано",
     "Owner" : "Власник",
     "Sharing" : "Поділитися",
     "Select a user or group" : "Виберіть користувача або групу",
@@ -196,7 +203,8 @@ OC.L10N.register(
     "Allow editing" : "Дозволити редагування",
     "Allow resharing" : "Дозволити передавати у спільний доступ іншим",
     "Remove share" : "Вилучити спільний доступ",
-    "Link copied" : "Посилання скопійовано",
+    "Failed to save settings" : "Неможливо зберегти налаштування",
+    "Failed to load settings" : "Не вдалося завантажити налаштування",
     "Privacy" : "Конфіденційність",
     "The app will try to access web pages that you add to automatically add information about them." : "Цей застосунок спробує отримати доступ до вебсторінок, які буде додано для автоматичного отримання інформації про них.",
     "Enable accessing and collecting information from the web pages you add" : "Увімкнути доступ та збір інформаці від вебсторінок, які ви додаєте",
@@ -212,8 +220,6 @@ OC.L10N.register(
     "Generic API URL" : "Загальне посилання API",
     "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Просто встановіть Pageres CLI від Синдра Соргуса на вашому сервері, а застосунок \"Закладки\" сам його ідентифікує. Також можна додати змінні оточення ENV, які вестимуть до Pageres, напр., як це зазначено у заповнювачі:",
     "Pageres ENV variables" : "Змінні оточення ENV Pageres",
-    "Failed to save settings" : "Неможливо зберегти налаштування",
-    "Failed to load settings" : "Не вдалося завантажити налаштування",
     "This URL is already bookmarked! Overwrite?" : "Цей URL вже є в закладках! Перезаписати?",
     "Enter bookmark title" : "Зазначте назву закладки",
     "Enter bookmark URL" : "Зазначте посилання закладки",
